@@ -193,6 +193,7 @@ class ftpclient:
 				return C_NG
 			res = self.createLocalDir(remote_dir)
 			if res == C_NG:
+				res = self.changeRemoteDir("..")
 				return C_NG
 			res = self.changeLocalDir(remote_dir)
 			if res == C_NG:
@@ -205,8 +206,10 @@ class ftpclient:
 					if ent <> "":
 						line_ent.append(ent)
 				if line[0] == "d":
-					self.getRemoteDir(line_ent[8])
+					if line_ent[8] <> ".." and line_ent[8] <> ".":
+						self.getRemoteDir(line_ent[8])
 				elif line[0] == "-":
+					#print self.ftpcon.pwd() + "/" + line_ent[8]
 					self.getRemoteFile(line_ent[8],line_ent[8])
 					if res == C_NG:
 						return C_NG
@@ -218,7 +221,6 @@ class ftpclient:
 				return C_NG
 			return C_OK
 		except Exception, e:
-			print "e"
 			self.error_obj = e
 			return C_NG
 
@@ -234,9 +236,8 @@ class ftpclient:
 	#Change local dir
 	def changeLocalDir(self,dir_name):
 		try:
-			if os.path.exists(dir_name):
-				os.chdir(dir_name)
-				return C_OK
+			os.chdir(dir_name)
+			return C_OK
 		except Exception, e:
 			self.error_obj = e
 			return C_NG
@@ -250,6 +251,7 @@ class ftpclient:
 		except Exception, e:
 			self.error_obj = e
 			return C_NG
+			
 	#Set pasv mode
 	def setPasvmode(self):
 		try:
@@ -282,6 +284,15 @@ class ftpclient:
 			self.error_obj = e
 			return C_NG
 
+	#Rename file
+	def renameRemoteFile(self,from_filename,to_filename):
+		try:
+			self.ftpcon.rename(from_filename,to_filename)
+			return C_OK
+		except Exception, e:
+			self.error_obj = e
+			return C_NG
+	
 	#Class initial
 	def __init__(self):
 		self.hostname = ""
