@@ -36,6 +36,8 @@ class ftpy:
 			res = self.ftpclient.login()
 			if res <> C_OK:
 				self.printError("Login Failure:",self.ftpclient.getError_Obj())
+			else:
+				self.connectFlag = C_ON
 		else:
 			self.printError("Connection Error:",self.ftpclient.getError_Obj())
 			
@@ -46,12 +48,15 @@ class ftpy:
 	#Open Connection
 	def open(self,command):
 		if len(command) == 2:
-			hostname = command[1]
-			try:
-				socket.gethostbyname(hostname)
-				self.connect(hostname,None)
-			except Exception, e:
-				print "Could not find server."
+			if self.connectFlag == C_OFF:
+				hostname = command[1]
+				try:
+					socket.gethostbyname(hostname)
+					self.connect(hostname,None)
+				except Exception, e:
+					print "Could not find server."
+			else:
+				print "Already connected , use close first."
 		else:
 			print "usage : open <hostname>"
 
@@ -181,6 +186,19 @@ class ftpy:
 		else:
 			print "usage : lcd <dir_name>"
 
+	#Rename Remote File
+	def rename(self,command):
+		if len(command) == 3:
+			res = self.ftpclient.renameRemoteFile(command[1],command[2])
+			if res <> C_OK:
+				self.printError("Connection Error:",self.ftpclient.getError_Obj())
+		else:
+			print "usage : rename <from_filename> <to_filename>"
+
+	#Output Help
+	def help(self):
+		self.ftpui.printHelp()
+
 	#Output prompt and Input command
 	def prompt(self):
 		command = self.ftpui.user_input()
@@ -219,6 +237,10 @@ class ftpy:
 			self.lpwd()
 		elif command[0] == "lcd":
 			self.lcd(command)
+		elif command[0] == "rename":
+			self.rename(command)
+		elif command[0] == "help":
+			self.help()
 		else:
 			print "?Invalid command"
 		return 1
@@ -233,6 +255,7 @@ class ftpy:
 		self.ftpclient = ftpclient.ftpclient()
 		self.ftpui = ftpui.ftpui()
 		res = C_OK
+		self.connectFlag = C_OFF
 		if pasv == True:
 			res = self.ftpclient.setPasvmode()
 		if hostname <> "":
